@@ -22,8 +22,9 @@
 
 
 #include <config.h>
-#include "dialog.h"
+#include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-window-icon.h>
+#include "dialog.h"
 #include "properties.h"
 
 #define GTK_HTML_EDIT_IMAGE_BWIDTH      0
@@ -68,7 +69,7 @@ apply (GtkHTMLEditPropertiesDialog *d)
 static void
 prop_close (GtkHTMLEditPropertiesDialog *d)
 {
-	gtk_dialog_response (GTK_DIALOG (d->dialog), GTK_RESPONSE_CLOSE);
+	gtk_dialog_response (GTK_DIALOG (d->dialog), GTK_RESPONSE_CANCEL);
 	gtk_html_edit_properties_dialog_destroy (d);
 }
 
@@ -99,7 +100,7 @@ static void
 dialog_response (GtkDialog *dialog, gint response_id, GtkHTMLEditPropertiesDialog *d)
 {
 	switch (response_id) {
-	case GTK_RESPONSE_CLOSE:
+	case GTK_RESPONSE_CANCEL:
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
 	case 0: /* OK */
@@ -113,30 +114,58 @@ dialog_response (GtkDialog *dialog, gint response_id, GtkHTMLEditPropertiesDialo
 	}
 }
 
+static gboolean stock_insert_added = FALSE;
+#define GTKHTML_STOCK_INSERT "gtkhtml-stock-insert"
+static GtkStockItem insert_items [] =
+{
+	{ GTKHTML_STOCK_INSERT, N_("Insert"), 0, 0, GETTEXT_PACKAGE }
+};
+
 GtkHTMLEditPropertiesDialog *
 gtk_html_edit_properties_dialog_new (GtkHTMLControlData *cd, gboolean insert, gchar *title, gchar *icon_path)
 {
 	GtkHTMLEditPropertiesDialog *d = g_new (GtkHTMLEditPropertiesDialog, 1);
+	GtkWidget *vbox;
 	GtkWindow *parent;
 
+	if (insert && !stock_insert_added) {
+		GtkIconSet *jumpto = gtk_icon_factory_lookup_default (GTK_STOCK_JUMP_TO);
+
+		if (jumpto) {
+			GtkIconFactory *factory = gtk_icon_factory_new ();
+
+			gtk_icon_factory_add (factory, GTKHTML_STOCK_INSERT, jumpto);
+			gtk_icon_factory_add_default (factory);
+		}
+		gtk_stock_add_static (insert_items, G_N_ELEMENTS (insert_items));
+		stock_insert_added = TRUE;
+	}
+
 	d->page_data      = NULL;
 	d->title          = g_strdup (title);
 	d->insert         = insert;
 	d->control_data   = cd;
 	parent = get_parent_window (GTK_WIDGET (cd->html));
 	d->dialog         = insert ? gtk_dialog_new_with_buttons (title, parent, 0,
-								  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-								  _("Insert"), 1,
+								  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+								  GTKHTML_STOCK_INSERT, 1,
 								  NULL)
 		:  gtk_dialog_new_with_buttons (title, parent, 0,
-						GTK_STOCK_APPLY, 1,
-						GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						GTK_STOCK_OK, 0,
 						NULL);
+
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (d->dialog)->vbox), 6);
+	gtk_container_set_border_width (GTK_CONTAINER (d->dialog), 6);
+
 	d->notebook = gtk_notebook_new ();
 	g_signal_connect (d->dialog, "destroy", G_CALLBACK (destroy_dialog), d);
 	g_signal_connect (d->notebook, "switch_page", G_CALLBACK (switch_page), d);
-	gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (d->dialog)->vbox), d->notebook);
+	vbox = gtk_vbox_new (FALSE, 6);
+	gtk_widget_show (vbox);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
+	gtk_box_pack_start_defaults (GTK_BOX (vbox), d->notebook);
+	gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (d->dialog)->vbox), vbox);
 	gtk_widget_show (d->notebook);
 
 	g_signal_connect (d->dialog, "response", G_CALLBACK (dialog_response), d);
@@ -145,6 +174,7 @@ gtk_html_edit_properties_dialog_new (GtkHTMLControlData *cd, gboolean insert, gc
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (d->dialog), 0, FALSE);
 	if (!insert)
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (d->dialog), 1, FALSE);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (d->dialog)->vbox), 6);
 
 	return d;
 }
@@ -199,6 +229,8 @@ gtk_html_edit_properties_dialog_show (GtkHTMLEditPropertiesDialog *d)
 	if (g_list_length (d->page_data) <= 1) {
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (d->notebook), FALSE);
 		gtk_notebook_set_show_border (GTK_NOTEBOOK (d->notebook), FALSE);
+		if (g_list_length (d->page_data) == 1)
+			gtk_container_set_border_width (GTK_CONTAINER (gtk_notebook_get_nth_page (GTK_NOTEBOOK (d->notebook), 0)), 0);
 	}
 	gtk_widget_show (d->dialog);
 }
@@ -207,7 +239,7 @@ void
 gtk_html_edit_properties_dialog_close (GtkHTMLEditPropertiesDialog *d)
 {
 	if (d->dialog)
-		gtk_dialog_response (GTK_DIALOG (d->dialog), GTK_RESPONSE_CLOSE);
+		gtk_dialog_response (GTK_DIALOG (d->dialog), GTK_RESPONSE_CANCEL);
 }
 
 void
